@@ -13,7 +13,7 @@
 namespace dht
 {
 /*!
- * FindNode response message for DHT
+ * \brief FindNode response message for DHT.
  */
 class KTORRENT_EXPORT FindNodeRsp : public RPCMsg, public PackedNodeContainer
 {
@@ -26,8 +26,6 @@ public:
     void print() override;
     void encode(QByteArray &arr) const override;
     void parse(bt::BDictNode *dict) override;
-
-    typedef QSharedPointer<FindNodeRsp> Ptr;
 };
 
 }
