@@ -13,7 +13,7 @@
 namespace dht
 {
 /*!
- * GetPeers request in the DHT protocol
+ * \brief GetPeers request in the DHT protocol.
  */
 class KTORRENT_EXPORT GetPeersReq : public RPCMsg
 {
@@ -33,8 +33,6 @@ public:
     void encode(QByteArray &arr) const override;
     void parse(bt::BDictNode *dict) override;
 
-    typedef QSharedPointer<GetPeersReq> Ptr;
-
 protected:
     Key info_hash;
     QStringList want;
