@@ -18,13 +18,12 @@ namespace net
 /*!
  * \author Joris Guisson <joris.guisson@gmail.com>
  *
- * Extends the TrafficShapedSocket with outbound bittorrent
- * packet queues.
+ * \brief Extends the TrafficShapedSocket with outbound bittorrent packet queues.
  */
 class PacketSocket : public TrafficShapedSocket
 {
 public:
-    PacketSocket(SocketDevice *sock);
+    PacketSocket(std::unique_ptr<SocketDevice> sock);
     PacketSocket(int fd, int ip_version);
     PacketSocket(bool tcp, int ip_version);
     ~PacketSocket() override;
