@@ -18,6 +18,7 @@
 #include <util/sha1hashgen.h>
 
 using namespace bt;
+using namespace Qt::Literals::StringLiterals;
 
 const bt::Uint32 TEST_FILE_SIZE = 5 * 1024 * 1024;
 
@@ -45,15 +46,15 @@ public:
 private Q_SLOTS:
     void initTestCase()
     {
-        QLocale::setDefault(QLocale("main"));
-        bt::InitLog("torrentfilestreamtest.log", false, false);
-        QVERIFY(creator.createSingleFileTorrent(TEST_FILE_SIZE, "test.avi"));
-        QVERIFY(creator2.createSingleFileTorrent(TEST_FILE_SIZE, "test2.avi"));
+        QLocale::setDefault(QLocale(u"main"_s));
+        bt::InitLog(u"torrentfilestreamtest.log"_s, false, false);
+        QVERIFY(creator.createSingleFileTorrent(TEST_FILE_SIZE, u"test.avi"_s));
+        QVERIFY(creator2.createSingleFileTorrent(TEST_FILE_SIZE, u"test2.avi"_s));
 
         Out(SYS_GEN | LOG_DEBUG) << "Created " << creator.torrentPath() << endl;
         Out(SYS_GEN | LOG_DEBUG) << "Created " << creator2.torrentPath() << endl;
         try {
-            tc.init(this, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0", creator.tempPath() + "data/");
+            tc.init(this, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0"_L1, creator.tempPath() + "data/"_L1);
             tc.createFiles();
             QVERIFY(tc.hasExistingFiles());
             tc.startDataCheck(false, 0, tc.getStats().total_chunks);
@@ -62,7 +63,7 @@ private Q_SLOTS:
             } while (tc.getStats().status == bt::CHECKING_DATA);
             QVERIFY(tc.getStats().completed);
 
-            incomplete_tc.init(this, bt::LoadFile(creator2.torrentPath()), creator2.tempPath() + "tor0", creator2.tempPath() + "data/");
+            incomplete_tc.init(this, bt::LoadFile(creator2.torrentPath()), creator2.tempPath() + "tor0"_L1, creator2.tempPath() + "data/"_L1);
             incomplete_tc.createFiles();
         } catch (bt::Error &err) {
             Out(SYS_GEN | LOG_DEBUG) << "Failed to load torrent: " << creator.torrentPath() << endl;
@@ -91,7 +92,7 @@ private Q_SLOTS:
             written += tc.getStats().chunk_size;
 
             // Verify the hash
-            bt::SHA1Hash hash = bt::SHA1Hash::generate((const bt::Uint8 *)tmp.data(), tmp.size());
+            bt::SHA1Hash hash = bt::SHA1Hash::generate(tmp);
             QVERIFY(hash == tc.getTorrent().getHash(idx));
             idx++;
         }
@@ -136,7 +137,7 @@ private Q_SLOTS:
             written += ret;
 
             // Verify the hash
-            bt::SHA1Hash hash = bt::SHA1Hash::generate((const bt::Uint8 *)tmp.data(), tmp.size());
+            bt::SHA1Hash hash = bt::SHA1Hash::generate(tmp);
             QVERIFY(hash == tc.getTorrent().getHash(idx));
             idx++;
         }
@@ -194,8 +195,9 @@ private Q_SLOTS:
         Out(SYS_GEN | LOG_DEBUG) << "chunk_off = " << chunk_off << endl;
 
         // Verify the hashes
+        const QByteArrayView range_view{range};
         for (int i = 0; i < 3; i++) {
-            bt::SHA1Hash hash = bt::SHA1Hash::generate((const bt::Uint8 *)range.data() + chunk_off, tc.getStats().chunk_size);
+            bt::SHA1Hash hash = bt::SHA1Hash::generate(range_view.sliced(chunk_off, tc.getStats().chunk_size));
 
             Out(SYS_GEN | LOG_DEBUG) << "chash = " << hash.toString() << endl;
             Out(SYS_GEN | LOG_DEBUG) << "whash = " << tc.getTorrent().getHash(chunk_idx).toString() << endl;
