@@ -27,25 +27,18 @@ class BNode;
 class BDictNode;
 class BListNode;
 
+/*!
+ * \brief A heirarchy of trackers for a torrent.
+ */
 struct TrackerTier {
     QList<QUrl> urls;
-    TrackerTier *next;
-
-    TrackerTier()
-        : next(nullptr)
-    {
-    }
-
-    ~TrackerTier()
-    {
-        delete next;
-    }
+    std::unique_ptr<TrackerTier> next;
 };
 
 /*!
  * \author Joris Guisson
  *
- * Listener base class, to get notified when the priority of a file changes.
+ * \brief Listener base class, to get notified when the priority of a file changes.
  */
 class KTORRENT_EXPORT FilePriorityListener
 {
@@ -59,7 +52,7 @@ public:
 
 /*!
  * \author Joris Guisson
- * \brief Loads a .torrent file
+ * \brief Loads a .torrent file.
  *
  * Loads a torrent file and calculates some miscelanious other data,
  * like the info_hash and the peer_id.
@@ -247,7 +240,7 @@ public:
     //! Gets a pointer to AnnounceList
     const TrackerTier *getTrackerList() const
     {
-        return trackers;
+        return trackers.get();
     }
 
     //! Get the number of initial DHT nodes
@@ -318,7 +311,7 @@ private:
     QList<QUrl> web_seeds;
     PeerID peer_id;
 
-    TrackerTier *trackers;
+    std::unique_ptr<TrackerTier> trackers;
     Uint64 chunk_size;
     Uint64 last_chunk_size;
     Uint64 total_size;
